@@ -15,8 +15,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -67,10 +67,10 @@ prepanel.default.densityplot <-
         yl <- 0
         dxl <- numeric(0) # bad names !!
         dyl <- numeric(0) 
-        for (i in seq(along=vals))
+        for (i in seq(along = vals))
         {
             id <- (groups[subscripts] == vals[i])
-            if (sum(id) > 1)
+            if (sum(id, na.rm = TRUE) > 1) ## need at least 2
             {
                 h <- do.call(density, c(list(x = x[id]), darg))
                 xl <- c(xl, h$x)
