@@ -15,8 +15,8 @@
 ###
 ### You should have received a copy of the GNU General Public
 ### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+### MA 02110-1301, USA
 
 
 
@@ -189,7 +189,7 @@ panel.tmd.qqmath <-
 tmd <- function(object, ...)  UseMethod("tmd")
 
 tmd.formula <-
-    function(object, data = parent.frame(), ...)
+    function(object, data = NULL, ...)
     tmd(xyplot(object, data = data, ...))
 
 tmd.trellis <-
